@@ -1,8 +1,15 @@
 from datetime import datetime
-from typing import List, Optional
+from typing import Dict, List, Optional
 
 from pydantic import BaseModel, validator
 
+from elementary.monitor.api.invocations.schema import DbtInvocationSchema
+from elementary.monitor.api.tests.schema import (
+    ModelUniqueIdType,
+    TestResultSchema,
+    TestRunSchema,
+    TotalsSchema,
+)
 from elementary.utils.log import get_logger
 from elementary.utils.time import DATETIME_FORMAT, convert_local_time_to_timezone
 
@@ -35,3 +42,14 @@ class DataMonitoringAlertsFilter(BaseModel):
     owner: Optional[str] = None
     model: Optional[str] = None
     node_names: Optional[List[str]] = None
+
+
+class DataMonitoringReportTestResultsSchema(BaseModel):
+    results: Dict[Optional[ModelUniqueIdType], List[TestResultSchema]] = dict()
+    totals: Dict[Optional[str], TotalsSchema] = dict()
+    invocation: DbtInvocationSchema = dict()
+
+
+class DataMonitoringReportTestRunsSchema(BaseModel):
+    runs: Dict[Optional[ModelUniqueIdType], List[TestRunSchema]] = dict()
+    totals: Dict[Optional[str], TotalsSchema] = dict()
