@@ -9,7 +9,7 @@ import posthog
 from pydantic import BaseModel
 
 import elementary.exceptions.exceptions
-import elementary.tracking.env
+import elementary.tracking.runner
 from elementary.clients.dbt.dbt_runner import DbtRunner
 from elementary.config.config import Config
 from elementary.monitor import dbt_project_utils
@@ -25,19 +25,19 @@ class AnonymousWarehouse(BaseModel):
 
 
 class AnonymousTracking:
-    ANONYMOUS_USER_ID_FILE = ".user_id"
+    _ANONYMOUS_USER_ID_FILE = ".user_id"
+    _INTERNAL_EXCEPTIONS_LIMIT = 5
+
     POSTHOG_PROJECT_API_KEY = "phc_56XBEzZmh02mGkadqLiYW51eECyYKWPyecVwkGdGUfg"
 
-    INTERNAL_EXCEPTIONS_LIMIT = 5
-
     def __init__(self, config: Config) -> None:
-        self._env_props = {}
+        self._props = {}
         self.anonymous_user_id = None
         self.anonymous_warehouse = None
-        self.config = config
-        self.do_not_track = config.anonymous_tracking_enabled is False
-        self.run_id = str(uuid.uuid4())
-        self.init()
+        self._config = config
+        self._do_not_track = config.anonymous_tracking_enabled is False
+        self._run_id = str(uuid.uuid4())
+        self._init()
 
         # Exceptions that occurred during the run of the CLI, but don't fail the entire run.
         # We want to avoid sending an event for each one of these (as there might be many of them), so we will send
@@ -45,18 +45,18 @@ class AnonymousTracking:
         self.internal_exceptions = []
         self.internal_exceptions_count = 0
 
-    def init(self):
+    def _init(self):
         try:
             posthog.project_api_key = self.POSTHOG_PROJECT_API_KEY
-            self._env_props.update(elementary.tracking.env.get_props())
+            self._props["env"] = elementary.tracking.runner.get_props()
             self.anonymous_user_id = self._get_anonymous_user_id()
             self.anonymous_warehouse = self._get_anonymous_warehouse()
         except Exception:
-            pass
+            logger.debug("Unable to initialize anonymous tracking.", exc_info=True)
 
     def _get_anonymous_user_id(self):
         user_id_path = Path().joinpath(
-            self.config.config_dir, self.ANONYMOUS_USER_ID_FILE
+            self._config.config_dir, self._ANONYMOUS_USER_ID_FILE
         )
         try:
             return user_id_path.read_text()
@@ -69,9 +69,9 @@ class AnonymousTracking:
             pass
         return user_id
 
-    def send_event(self, name: str, properties: dict = None) -> None:
+    def _send_event(self, name: str, properties: dict = None) -> None:
         try:
-            if self.do_not_track:
+            if self._do_not_track:
                 return
 
             if properties is None:
@@ -81,8 +81,8 @@ class AnonymousTracking:
                 distinct_id=self.anonymous_user_id,
                 event=name,
                 properties={
-                    "run_id": self.run_id,
-                    "env": self._env_props,
+                    "run_id": self._run_id,
+                    **self._props,
                     **properties,
                 },
                 groups={
@@ -95,19 +95,25 @@ class AnonymousTracking:
             logger.debug("Unable to send tracking event.", exc_info=True)
 
     def track_cli_start(
-        self, module_name: str, cli_properties: dict, command: str = None
+        self,
+        module_name: str,
+        cli_properties: Optional[dict] = None,
+        command: Optional[str] = None,
     ):
         props = {
             "cli_properties": cli_properties,
             "module_name": module_name,
             "command": command,
-            "env": self.config.env,
-            "has_project_dir": bool(self.config.project_dir),
+            "edr_env": self._config.env,
+            "has_project_dir": bool(self._config.project_dir),
         }
-        self.send_event("cli-start", properties=props)
+        self._send_event("cli-start", properties=props)
 
     def track_cli_end(
-        self, module_name: str, execution_properties: dict, command: str = None
+        self,
+        module_name: str,
+        execution_properties: Optional[dict],
+        command: Optional[str] = None,
     ):
         props = {
             "execution_properties": execution_properties,
@@ -117,7 +123,7 @@ class AnonymousTracking:
         if self.internal_exceptions_count > 0:
             props["internal_exceptions"] = self.internal_exceptions
             props["internal_exceptions_count"] = self.internal_exceptions_count
-        self.send_event("cli-end", properties=props)
+        self._send_event("cli-end", properties=props)
 
     def track_cli_exception(
         self, module_name: str, exc: Exception, command: str = None
@@ -128,11 +134,11 @@ class AnonymousTracking:
         }
         props.update(self._get_exception_properties(exc))
 
-        self.send_event("cli-exception", properties=props)
+        self._send_event("cli-exception", properties=props)
 
     def record_cli_internal_exception(self, exc: Exception):
         self.internal_exceptions_count += 1
-        if len(self.internal_exceptions) < self.INTERNAL_EXCEPTIONS_LIMIT:
+        if len(self.internal_exceptions) < self._INTERNAL_EXCEPTIONS_LIMIT:
             self.internal_exceptions.append(self._get_exception_properties(exc))
 
     @staticmethod
@@ -143,15 +149,15 @@ class AnonymousTracking:
         return props
 
     def track_cli_help(self):
-        self.send_event("cli-help")
+        self._send_event("cli-help")
 
     def _get_anonymous_warehouse(self) -> Optional[AnonymousWarehouse]:
         try:
             dbt_runner = DbtRunner(
                 dbt_project_utils.PATH,
-                self.config.profiles_dir,
-                self.config.profile_target,
-                dbt_env_vars=self.config.dbt_env_vars,
+                self._config.profiles_dir,
+                self._config.profile_target,
+                dbt_env_vars=self._config.dbt_env_vars,
             )
             if not dbt_project_utils.dbt_package_exists():
                 dbt_runner.deps(quiet=True)
@@ -174,4 +180,4 @@ class AnonymousTracking:
             return None
 
     def set_env(self, key: str, value):
-        self._env_props[key] = value
+        self._props[key] = value
